@@ -13,9 +13,10 @@ from order.mixins import CopyMixin, AuxDataMixin, TagMixin, SelectionMixin, Labe
 from order.util import to_root_latex
 
 
-@unique_tree(plural="categories", parents=-1, deep_children=True, deep_parents=True)
+@unique_tree(parents=-1, deep_children=True, deep_parents=True)
 class Category(UniqueObject, CopyMixin, AuxDataMixin, TagMixin, SelectionMixin, LabelMixin):
-    """ __init__(name, id="+", channel=None, categories=None, label=None, label_short=None, selection=None, selection_mode=None, tags=None, aux=None, context=None)
+    """ __init__(name, id="+", channel=None, categories=None, label=None, label_short=None, \\
+    selection=None, selection_mode=None, tags=None, aux=None, context=None)
     Class that describes an analysis category. This is not to be confused with an analysis
     :py:class:`Channel`. While the definition of a channel can be understood as being fixed by e.g.
     the final state of an event, a category describes an arbitrary sub phase-space. Therefore, a
@@ -128,6 +129,9 @@ class Category(UniqueObject, CopyMixin, AuxDataMixin, TagMixin, SelectionMixin,
        converted to ROOT-style latex.
     """
 
+    cls_name_singular = "category"
+    cls_name_plural = "categories"
+
     # attributes for copying
     copy_specs = [{"attr": "channel", "ref": True}] + UniqueObject.copy_specs + \
         AuxDataMixin.copy_specs + TagMixin.copy_specs + SelectionMixin.copy_specs + \
@@ -253,6 +257,9 @@ class Channel(UniqueObject, CopyMixin, AuxDataMixin, TagMixin, LabelMixin):
     **Members**
     """
 
+    cls_name_singular = "channel"
+    cls_name_plural = "channels"
+
     # attributes for copying
     copy_specs = UniqueObject.copy_specs + AuxDataMixin.copy_specs + TagMixin.copy_specs + \
         LabelMixin.copy_specs
